import os
from django.core.management.templates import TemplateCommand


class Command(TemplateCommand):
    help = "Starts an app the clean way"

    def handle(self, *args, **options):
        app_name = options.pop("name")
        target = options.pop("directory")
        options["template"] = os.path.join(
            os.path.dirname(os.path.dirname(os.path.dirname(os.path.abspath(__file__)))), "_app_template"
        )
        super().handle("app", app_name, target, **options)
        print(f"Creating {app_name}")



from importlib import import_module

from django.apps import AppConfig
from django.conf import settings
from django.contrib.admin import site, AdminSite
from django.utils.module_loading import autodiscover_modules


class CleanAppConfig(AppConfig):
    CUSTOM_MODELS_MODULE = getattr(settings, "CUSTOM_MODELS_MODULE", "models")
    CUSTOM_MIGRATIONS_MODULE = getattr(settings, "CUSTOM_MIGRATIONS_MODULE", "migrations")
    CUSTOM_ADMIN_MODULE = getattr(settings, "CUSTOM_ADMIN_MODULE", "admin")

    def import_models(self) -> None:
        super().import_models()
        self.__load_custom_models_module()

    def __load_custom_models_module(self) -> None:
        self.models_module = import_module(f"{self.label}.{self.CUSTOM_MODELS_MODULE}")

    def ready(self) -> None:
        self.__load_custom_admin_module(self.CUSTOM_ADMIN_MODULE, register_to=site)
        self.__load_custom_migration_module(self.CUSTOM_MIGRATIONS_MODULE)

    def __load_custom_admin_module(self, admin_module: str, register_to: AdminSite) -> None:
        autodiscover_modules(admin_module, register_to=register_to)

    def __load_custom_migration_module(self, migration_module: str) -> None:
        settings.MIGRATION_MODULES.update(**{self.label: f"{self.label}.{migration_module}"})



from setuptools import setup

with open("README.md", "r") as readme:
    README = readme.read()

version = "0.1.9"

setup(
    name="Django-ddd",
    version=version,
    url="https://github.com/jdiazromeral/django-ddd",
    license="MIT License",
    author="Javier Díaz-Romeral Torralbo",
    author_email="javierdiazromeral@gmail.com",
    description="An app for a cleaner Django",
    long_description=README,
    long_description_content_type="text/markdown",
    packages=["django_ddd"],
    zip_safe=False,
    include_package_data=True,
    platforms="any",
    install_requires=["Django>=3"],
    classifiers=[
        "Environment :: Web Environment",
        "Framework :: Django",
        "Framework :: Django :: 3.0",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3.8",
        "Topic :: Software Development :: Libraries",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Topic :: Software Development :: Quality Assurance",
        "Topic :: Utilities",
    ],
    python_requires=">=3.8",
)
